@@ -1,22 +1,16 @@
 #ifndef __CLUTTER_STAGE_COGL_H__
 #define __CLUTTER_STAGE_COGL_H__
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <glib-object.h>
+#include <cairo.h>
+#include <clutter/clutter-backend.h>
 #include <clutter/clutter-stage.h>
 
 #ifdef COGL_HAS_X11_SUPPORT
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
-#include "../x11/clutter-stage-x11.h"
 #endif
 
-#include "clutter-backend-cogl.h"
-
 G_BEGIN_DECLS
 
 #define CLUTTER_TYPE_STAGE_COGL                  (_clutter_stage_cogl_get_type ())
@@ -31,48 +25,48 @@ typedef struct _ClutterStageCoglClass    ClutterStageCoglClass;
 
 struct _ClutterStageCogl
 {
-#ifdef COGL_HAS_X11_SUPPORT
-
-  ClutterStageX11 parent_instance;
-
-#else
-
   GObject parent_instance;
 
  /* the stage wrapper */
-  ClutterStage      *wrapper;
+  ClutterStage *wrapper;
 
   /* back pointer to the backend */
-  ClutterBackendCogl *backend;
-
-#endif
+  ClutterBackend *backend;
 
   CoglOnscreen *onscreen;
 
+  gint64 last_presentation_time;
+  float refresh_rate;
+
+  gint64 update_time;
   gint pending_swaps;
-  unsigned int swap_callback_id;
+  CoglFrameClosure *frame_closure;
 
   /* We only enable clipped redraws after 2 frames, since we've seen
    * a lot of drivers can struggle to get going and may output some
    * junk frames to start with. */
   unsigned long frame_count;
 
-  ClutterGeometry bounding_redraw_clip;
+  cairo_rectangle_int_t bounding_redraw_clip;
 
   guint initialized_redraw_clip : 1;
 
   /* TRUE if the current paint cycle has a clipped redraw. In that
      case bounding_redraw_clip specifies the the bounds. */
   guint using_clipped_redraw : 1;
+
+  guint dirty_backbuffer     : 1;
+
+  /* Stores a list of previous damaged areas */
+#define DAMAGE_HISTORY_MAX 16
+#define DAMAGE_HISTORY(x) ((x) & (DAMAGE_HISTORY_MAX - 1))
+  cairo_rectangle_int_t damage_history[DAMAGE_HISTORY_MAX];
+  unsigned damage_index;
 };
 
 struct _ClutterStageCoglClass
 {
-#ifdef COGL_HAS_X11_SUPPORT
-  ClutterStageX11Class parent_class;
-#else
   GObjectClass parent_class;
-#endif
 };
 
 GType _clutter_stage_cogl_get_type (void) G_GNUC_CONST;
